## EN
    Simple API for stand2hacks
    Methods:
        account:
            Returns json containing all information about account
        getKeys:
            Returns json containing all keys on account
        keyInfo:
            Returns json containing information about specified key
        unlinkKey:
            Unlinks key from all devices. 1 key can be unlincked every 40 minutes.
## RU
    Простое API для stand2hacks
    Методы:
        account:
            Возвращает json содержащий всю информацию об аккаунте
        getKeys:
            Возвращает json содержащий все ключи на аккаунте
        keyInfo:
            Возвращает json содержащий всю информацию об определённом ключе
        unlinkKey:
            Отвязывает определенный ключ. 1 ключ можно отвязать раз в 40 минут.